# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.iam.v1 import iam_token_service_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2


class IamTokenServiceStub(object):
    """A set of methods for managing IAM tokens.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.iam.v1.IamTokenService/Create',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.FromString,
                )
        self.CreateForServiceAccount = channel.unary_unary(
                '/yandex.cloud.iam.v1.IamTokenService/CreateForServiceAccount',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenForServiceAccountRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.FromString,
                )
        self.Revoke = channel.unary_unary(
                '/yandex.cloud.iam.v1.IamTokenService/Revoke',
                request_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenResponse.FromString,
                )


class IamTokenServiceServicer(object):
    """A set of methods for managing IAM tokens.
    """

    def Create(self, request, context):
        """Create an IAM token for the specified identity.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateForServiceAccount(self, request, context):
        """Create an IAM token for service account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Revoke(self, request, context):
        """Revoke the IAM token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IamTokenServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.SerializeToString,
            ),
            'CreateForServiceAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateForServiceAccount,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenForServiceAccountRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.SerializeToString,
            ),
            'Revoke': grpc.unary_unary_rpc_method_handler(
                    servicer.Revoke,
                    request_deserializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.iam.v1.IamTokenService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IamTokenService(object):
    """A set of methods for managing IAM tokens.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.IamTokenService/Create',
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateForServiceAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.IamTokenService/CreateForServiceAccount',
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenForServiceAccountRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.CreateIamTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Revoke(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iam.v1.IamTokenService/Revoke',
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenRequest.SerializeToString,
            yandex_dot_cloud_dot_iam_dot_v1_dot_iam__token__service__pb2.RevokeIamTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/face_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v1 import primitives_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v1_dot_primitives__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/vision/v1/face_detection.proto\x12\x19yandex.cloud.ai.vision.v1\x1a*yandex/cloud/ai/vision/v1/primitives.proto\"@\n\x0e\x46\x61\x63\x65\x41nnotation\x12.\n\x05\x66\x61\x63\x65s\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.ai.vision.v1.Face\"@\n\x04\x46\x61\x63\x65\x12\x38\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\".yandex.cloud.ai.vision.v1.PolygonBe\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v1.face_detection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision'
  _globals['_FACEANNOTATION']._serialized_start=121
  _globals['_FACEANNOTATION']._serialized_end=185
  _globals['_FACE']._serialized_start=187
  _globals['_FACE']._serialized_end=251
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.tuning.v1 import tuning_service_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class TuningServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tune = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
                )
        self.Describe = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
                )
        self.GetMetricsUrl = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
                )
        self.GetOptions = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
                )


class TuningServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Tune(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Describe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricsUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOptions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TuningServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tune': grpc.unary_unary_rpc_method_handler(
                    servicer.Tune,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.SerializeToString,
            ),
            'Describe': grpc.unary_unary_rpc_method_handler(
                    servicer.Describe,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.SerializeToString,
            ),
            'GetMetricsUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricsUrl,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.SerializeToString,
            ),
            'GetOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOptions,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.tuning.v1.TuningService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TuningService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Tune(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/List',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Describe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetricsUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.common.tag_pb2
import yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Details(google.protobuf.message.Message):
    """Test meta information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    LOGGING_LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    ARTIFACT_SETTINGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the test."""
    description: builtins.str
    """Description of the test."""
    logging_log_group_id: builtins.str
    """ID of the logging group to which test artifacts are uploaded."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.common.tag_pb2.Tag]:
        """Tags assigned to the test."""

    @property
    def artifact_settings(self) -> yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2.ArtifactSettings:
        """Settings which define where to upload test artifacts and which files should be included."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.common.tag_pb2.Tag] | None = ...,
        logging_log_group_id: builtins.str = ...,
        artifact_settings: yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2.ArtifactSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["artifact_settings", b"artifact_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["artifact_settings", b"artifact_settings", "description", b"description", "logging_log_group_id", b"logging_log_group_id", "name", b"name", "tags", b"tags"]) -> None: ...

global___Details = Details



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.smartwebsecurity.v1.waf import rule_set_descriptor_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_waf_dot_rule__set__descriptor__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor_service.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a>yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"H\n\x1bGetRuleSetDescriptorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xe3\x01\n\x18RuleSetDescriptorService\x12\xc6\x01\n\x03Get\x12\x41.yandex.cloud.smartwebsecurity.v1.waf.GetRuleSetDescriptorRequest\x1a\x37.yandex.cloud.smartwebsecurity.v1.waf.RuleSetDescriptor\"C\x82\xd3\xe4\x93\x02=\x12;/smartwebsecurity/v1/wafRuleSetDescriptors/{name}/{version}B\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.rule_set_descriptor_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['name']._options = None
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['version']._options = None
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['version']._serialized_options = b'\350\3071\001'
  _RULESETDESCRIPTORSERVICE.methods_by_name['Get']._options = None
  _RULESETDESCRIPTORSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/smartwebsecurity/v1/wafRuleSetDescriptors/{name}/{version}'
  _globals['_GETRULESETDESCRIPTORREQUEST']._serialized_start=237
  _globals['_GETRULESETDESCRIPTORREQUEST']._serialized_end=309
  _globals['_RULESETDESCRIPTORSERVICE']._serialized_start=312
  _globals['_RULESETDESCRIPTORSERVICE']._serialized_end=539
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Blob(google.protobuf.message.Message):
    """A Blob resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URLS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the blob."""
    digest: builtins.str
    """Content-addressable identifier of the blob."""
    size: builtins.int
    """Size of the blob, specified in bytes."""
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of blob urls."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        digest: builtins.str = ...,
        size: builtins.int = ...,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["digest", b"digest", "id", b"id", "size", b"size", "urls", b"urls"]) -> None: ...

global___Blob = Blob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PostgresObjectTransferSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEQUENCE_FIELD_NUMBER: builtins.int
    SEQUENCE_OWNED_BY_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    PRIMARY_KEY_FIELD_NUMBER: builtins.int
    FK_CONSTRAINT_FIELD_NUMBER: builtins.int
    DEFAULT_VALUES_FIELD_NUMBER: builtins.int
    CONSTRAINT_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    CAST_FIELD_NUMBER: builtins.int
    MATERIALIZED_VIEW_FIELD_NUMBER: builtins.int
    SEQUENCE_SET_FIELD_NUMBER: builtins.int
    sequence: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Sequences

    CREATE SEQUENCE ...
    """
    sequence_owned_by: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Owned sequences

    CREATE SEQUENCE ... OWNED BY ...
    """
    table: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Tables

    CREATE TABLE ...
    """
    primary_key: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Primary keys

    ALTER TABLE ... ADD PRIMARY KEY ...
    """
    fk_constraint: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Foreign keys

    ALTER TABLE ... ADD FOREIGN KEY ...
    """
    default_values: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Default values

    ALTER TABLE ... ALTER COLUMN ... SET DEFAULT ...
    """
    constraint: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Constraints

    ALTER TABLE ... ADD CONSTRAINT ...
    """
    index: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Indexes

    CREATE INDEX ...
    """
    view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Views

    CREATE VIEW ...
    """
    function: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Functions

    CREATE FUNCTION ...
    """
    trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Triggers

    CREATE TRIGGER ...
    """
    type: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Types

    CREATE TYPE ...
    """
    rule: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Rules

    CREATE RULE ...
    """
    collation: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Collations

    CREATE COLLATION ...
    """
    policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Policies

    CREATE POLICY ...
    """
    cast: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Casts

    CREATE CAST ...
    """
    materialized_view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """Materialized views

    CREATE MATERIALIZED VIEW ...
    """
    sequence_set: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType
    """"""
    def __init__(
        self,
        *,
        sequence: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        sequence_owned_by: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        table: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        primary_key: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        fk_constraint: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        default_values: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        constraint: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        index: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        function: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        trigger: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        type: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        rule: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        collation: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        cast: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        materialized_view: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
        sequence_set: yandex.cloud.datatransfer.v1.endpoint.common_pb2.ObjectTransferStage.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cast", b"cast", "collation", b"collation", "constraint", b"constraint", "default_values", b"default_values", "fk_constraint", b"fk_constraint", "function", b"function", "index", b"index", "materialized_view", b"materialized_view", "policy", b"policy", "primary_key", b"primary_key", "rule", b"rule", "sequence", b"sequence", "sequence_owned_by", b"sequence_owned_by", "sequence_set", b"sequence_set", "table", b"table", "trigger", b"trigger", "type", b"type", "view", b"view"]) -> None: ...

global___PostgresObjectTransferSettings = PostgresObjectTransferSettings

@typing.final
class OnPremisePostgres(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    port: builtins.int
    """Will be used if the cluster ID is not specified."""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode:
        """TLS settings for server connection. Disabled by default."""

    def __init__(
        self,
        *,
        port: builtins.int = ...,
        subnet_id: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "port", b"port", "subnet_id", b"subnet_id", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremisePostgres = OnPremisePostgres

@typing.final
class PostgresConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    """Managed Service for PostgreSQL cluster ID"""
    @property
    def on_premise(self) -> global___OnPremisePostgres:
        """Connection options for on-premise PostgreSQL"""

    def __init__(
        self,
        *,
        mdb_cluster_id: builtins.str = ...,
        on_premise: global___OnPremisePostgres | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["mdb_cluster_id", "on_premise"] | None: ...

global___PostgresConnection = PostgresConnection

@typing.final
class PostgresSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    INCLUDE_TABLES_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_FIELD_NUMBER: builtins.int
    SLOT_BYTE_LAG_LIMIT_FIELD_NUMBER: builtins.int
    SERVICE_SCHEMA_FIELD_NUMBER: builtins.int
    OBJECT_TRANSFER_SETTINGS_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name"""
    user: builtins.str
    """User for database access. not required as may be in connection"""
    slot_byte_lag_limit: builtins.int
    """Maximum lag of replication slot (in bytes); after exceeding this limit
    replication will be aborted.
    """
    service_schema: builtins.str
    """Database schema for service tables (__consumer_keeper,
    __data_transfer_mole_finder). Default is public
    """
    @property
    def connection(self) -> global___PostgresConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def include_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Included tables

        If none or empty list is presented, all tables are replicated. Full table name
        with schema. Can contain schema_name.* patterns.
        """

    @property
    def exclude_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Excluded tables

        If none or empty list is presented, all tables are replicated. Full table name
        with schema. Can contain schema_name.* patterns.
        """

    @property
    def object_transfer_settings(self) -> global___PostgresObjectTransferSettings:
        """Select database objects to be transferred during activation or deactivation."""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___PostgresConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        include_tables: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables: collections.abc.Iterable[builtins.str] | None = ...,
        slot_byte_lag_limit: builtins.int = ...,
        service_schema: builtins.str = ...,
        object_transfer_settings: global___PostgresObjectTransferSettings | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "object_transfer_settings", b"object_transfer_settings", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "database", b"database", "exclude_tables", b"exclude_tables", "include_tables", b"include_tables", "object_transfer_settings", b"object_transfer_settings", "password", b"password", "security_groups", b"security_groups", "service_schema", b"service_schema", "slot_byte_lag_limit", b"slot_byte_lag_limit", "user", b"user"]) -> None: ...

global___PostgresSource = PostgresSource

@typing.final
class PostgresTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name"""
    user: builtins.str
    """User for database access. not required as may be in connection"""
    cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType
    """Cleanup policy for activate, reactivate and reupload processes. Default is
    truncate.
    """
    @property
    def connection(self) -> global___PostgresConnection:
        """Database connection settings"""

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for database access."""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        connection: global___PostgresConnection | None = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "connection", b"connection", "database", b"database", "password", b"password", "security_groups", b"security_groups", "user", b"user"]) -> None: ...

global___PostgresTarget = PostgresTarget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/k8s/v1/node_group_service.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a$yandex/cloud/k8s/v1/node_group.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"2\n\x13GetNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x15ListNodeGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"f\n\x16ListNodeGroupsResponse\x12\x33\n\x0bnode_groups\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.NodeGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x19ListNodeGroupNodesRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x1aListNodeGroupNodesResponse\x12(\n\x05nodes\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.k8s.v1.Node\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x16\x44\x65leteNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\xa2\x08\n\x16UpdateNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\rnode_template\x18\x08 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplate\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicy\x12I\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\x0f \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x37\n\x07version\x18\n \x01(\x0b\x32&.yandex.cloud.k8s.v1.UpdateVersionSpec\x12K\n\x12maintenance_policy\x18\x0b \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\x0c \x03(\tBO\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x8a\xc8\x31\x05<=253\x12/\n\x0bnode_taints\x18\r \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0e \x03(\x0b\x32;.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"6\n\x17UpdateNodeGroupMetadata\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xcc\x07\n\x16\x43reateNodeGroupRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12>\n\rnode_template\x18\x05 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplateB\x04\xe8\xc7\x31\x01\x12<\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicyB\x04\xe8\xc7\x31\x01\x12I\n\x11\x61llocation_policy\x18\x07 \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\r \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x0f\n\x07version\x18\x08 \x01(\t\x12K\n\x12maintenance_policy\x18\t \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\n \x03(\tBO\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x8a\xc8\x31\x05<=253\x12/\n\x0bnode_taints\x18\x0b \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0c \x03(\x0b\x32;.yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x17\x43reateNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"5\n\x1c\x41utoUpgradeNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\x97\x01\n\x1eListNodeGroupOperationsRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListNodeGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc1\t\n\x10NodeGroupService\x12\x8a\x01\n\x03Get\x12(.yandex.cloud.k8s.v1.GetNodeGroupRequest\x1a\x1e.yandex.cloud.k8s.v1.NodeGroup\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}\x12\x8a\x01\n\x04List\x12*.yandex.cloud.k8s.v1.ListNodeGroupsRequest\x1a+.yandex.cloud.k8s.v1.ListNodeGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-kubernetes/v1/nodeGroups\x12\xae\x01\n\x06\x43reate\x12+.yandex.cloud.k8s.v1.CreateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*$\n\x17\x43reateNodeGroupMetadata\x12\tNodeGroup\x82\xd3\xe4\x93\x02&\"!/managed-kubernetes/v1/nodeGroups:\x01*\x12\xbe\x01\n\x06Update\x12+.yandex.cloud.k8s.v1.UpdateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*$\n\x17UpdateNodeGroupMetadata\x12\tNodeGroup\x82\xd3\xe4\x93\x02\x36\x32\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}:\x01*\x12\xc7\x01\n\x06\x44\x65lete\x12+.yandex.cloud.k8s.v1.DeleteNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/managed-kubernetes/v1/nodeGroups/{node_group_id}\x12\xc1\x01\n\x0eListOperations\x12\x33.yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest\x1a\x34.yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse\"D\x82\xd3\xe4\x93\x02>\x12</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations\x12\x92\x01\n\tListNodes\x12..yandex.cloud.k8s.v1.ListNodeGroupNodesRequest\x1a/.yandex.cloud.k8s.v1.ListNodeGroupNodesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-kubernetes/v1/nodesBV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.node_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _GETNODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _GETNODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTNODEGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['node_group_id']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DELETENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _DELETENODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _UPDATENODEGROUPREQUEST_LABELSENTRY._options = None
  _UPDATENODEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATENODEGROUPREQUEST_NODELABELSENTRY._options = None
  _UPDATENODEGROUPREQUEST_NODELABELSENTRY._serialized_options = b'8\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATENODEGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATENODEGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._serialized_options = b'\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\212\3101\005<=253'
  _UPDATENODEGROUPMETADATA.fields_by_name['node_group_id']._options = None
  _UPDATENODEGROUPMETADATA.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST_LABELSENTRY._options = None
  _CREATENODEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATENODEGROUPREQUEST_NODELABELSENTRY._options = None
  _CREATENODEGROUPREQUEST_NODELABELSENTRY._serialized_options = b'8\001'
  _CREATENODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['name']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATENODEGROUPREQUEST.fields_by_name['description']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATENODEGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATENODEGROUPREQUEST.fields_by_name['node_template']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['node_template']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['scale_policy']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._serialized_options = b'\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\212\3101\005<=253'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['node_group_id']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _NODEGROUPSERVICE.methods_by_name['Get']._options = None
  _NODEGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/managed-kubernetes/v1/nodeGroups/{node_group_id}'
  _NODEGROUPSERVICE.methods_by_name['List']._options = None
  _NODEGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/managed-kubernetes/v1/nodeGroups'
  _NODEGROUPSERVICE.methods_by_name['Create']._options = None
  _NODEGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateNodeGroupMetadata\022\tNodeGroup\202\323\344\223\002&\"!/managed-kubernetes/v1/nodeGroups:\001*'
  _NODEGROUPSERVICE.methods_by_name['Update']._options = None
  _NODEGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateNodeGroupMetadata\022\tNodeGroup\202\323\344\223\002621/managed-kubernetes/v1/nodeGroups/{node_group_id}:\001*'
  _NODEGROUPSERVICE.methods_by_name['Delete']._options = None
  _NODEGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/managed-kubernetes/v1/nodeGroups/{node_group_id}'
  _NODEGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _NODEGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002>\022</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations'
  _NODEGROUPSERVICE.methods_by_name['ListNodes']._options = None
  _NODEGROUPSERVICE.methods_by_name['ListNodes']._serialized_options = b'\202\323\344\223\002\036\022\034/managed-kubernetes/v1/nodes'
  _globals['_GETNODEGROUPREQUEST']._serialized_start=343
  _globals['_GETNODEGROUPREQUEST']._serialized_end=393
  _globals['_LISTNODEGROUPSREQUEST']._serialized_start=396
  _globals['_LISTNODEGROUPSREQUEST']._serialized_end=534
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_start=536
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_end=638
  _globals['_LISTNODEGROUPNODESREQUEST']._serialized_start=640
  _globals['_LISTNODEGROUPNODESREQUEST']._serialized_end=758
  _globals['_LISTNODEGROUPNODESRESPONSE']._serialized_start=760
  _globals['_LISTNODEGROUPNODESRESPONSE']._serialized_end=855
  _globals['_DELETENODEGROUPREQUEST']._serialized_start=857
  _globals['_DELETENODEGROUPREQUEST']._serialized_end=910
  _globals['_DELETENODEGROUPMETADATA']._serialized_start=912
  _globals['_DELETENODEGROUPMETADATA']._serialized_end=960
  _globals['_UPDATENODEGROUPREQUEST']._serialized_start=963
  _globals['_UPDATENODEGROUPREQUEST']._serialized_end=2021
  _globals['_UPDATENODEGROUPREQUEST_LABELSENTRY']._serialized_start=1919
  _globals['_UPDATENODEGROUPREQUEST_LABELSENTRY']._serialized_end=1964
  _globals['_UPDATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_start=1966
  _globals['_UPDATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_end=2015
  _globals['_UPDATENODEGROUPMETADATA']._serialized_start=2023
  _globals['_UPDATENODEGROUPMETADATA']._serialized_end=2077
  _globals['_CREATENODEGROUPREQUEST']._serialized_start=2080
  _globals['_CREATENODEGROUPREQUEST']._serialized_end=3052
  _globals['_CREATENODEGROUPREQUEST_LABELSENTRY']._serialized_start=1919
  _globals['_CREATENODEGROUPREQUEST_LABELSENTRY']._serialized_end=1964
  _globals['_CREATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_start=1966
  _globals['_CREATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_end=2015
  _globals['_CREATENODEGROUPMETADATA']._serialized_start=3054
  _globals['_CREATENODEGROUPMETADATA']._serialized_end=3102
  _globals['_AUTOUPGRADENODEGROUPMETADATA']._serialized_start=3104
  _globals['_AUTOUPGRADENODEGROUPMETADATA']._serialized_end=3157
  _globals['_LISTNODEGROUPOPERATIONSREQUEST']._serialized_start=3160
  _globals['_LISTNODEGROUPOPERATIONSREQUEST']._serialized_end=3311
  _globals['_LISTNODEGROUPOPERATIONSRESPONSE']._serialized_start=3313
  _globals['_LISTNODEGROUPOPERATIONSRESPONSE']._serialized_end=3426
  _globals['_NODEGROUPSERVICE']._serialized_start=3429
  _globals['_NODEGROUPSERVICE']._serialized_end=4646
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/translate/v2/translation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ai.translate.v2 import translation_pb2 as yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/translate/v2/translation_service.proto\x12\x1cyandex.cloud.ai.translate.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/ai/translate/v2/translation.proto\"\x95\x03\n\x10TranslateRequest\x12%\n\x14source_language_code\x18\x01 \x01(\tB\x07\x8a\xc8\x31\x03<=3\x12)\n\x14target_language_code\x18\x02 \x01(\tB\x0b\xe8\xc7\x31\x01\x8a\xc8\x31\x03<=3\x12\x45\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x35.yandex.cloud.ai.translate.v2.TranslateRequest.Format\x12\x15\n\x05texts\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x1b\n\tfolder_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x05model\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12N\n\x0fglossary_config\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.ai.translate.v2.TranslateGlossaryConfig\x12\x0f\n\x07speller\x18\x08 \x01(\x08\":\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nPLAIN_TEXT\x10\x01\x12\x08\n\x04HTML\x10\x02\"w\n\x17TranslateGlossaryConfig\x12\x43\n\rglossary_data\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.translate.v2.GlossaryDataH\x00\x42\x17\n\x0fglossary_source\x12\x04\xc0\xc1\x31\x01\"\\\n\x0cGlossaryData\x12L\n\x0eglossary_pairs\x18\x01 \x03(\x0b\x32*.yandex.cloud.ai.translate.v2.GlossaryPairB\x08\x82\xc8\x31\x04\x31-50\"W\n\x0cGlossaryPair\x12\x19\n\x0bsource_text\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0ftranslated_text\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\r\n\x05\x65xact\x18\x03 \x01(\x08\"W\n\x11TranslateResponse\x12\x42\n\x0ctranslations\x18\x01 \x03(\x0b\x32,.yandex.cloud.ai.translate.v2.TranslatedText\"\x80\x01\n\x15\x44\x65tectLanguageRequest\x12\x1c\n\x04text\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12,\n\x13language_code_hints\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x04<=10\x8a\xc8\x31\x03<=3\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"/\n\x16\x44\x65tectLanguageResponse\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"3\n\x14ListLanguagesRequest\x12\x1b\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"R\n\x15ListLanguagesResponse\x12\x39\n\tlanguages\x18\x01 \x03(\x0b\x32&.yandex.cloud.ai.translate.v2.Language2\xe5\x03\n\x12TranslationService\x12\x90\x01\n\tTranslate\x12..yandex.cloud.ai.translate.v2.TranslateRequest\x1a/.yandex.cloud.ai.translate.v2.TranslateResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/translate/v2/translate:\x01*\x12\x9c\x01\n\x0e\x44\x65tectLanguage\x12\x33.yandex.cloud.ai.translate.v2.DetectLanguageRequest\x1a\x34.yandex.cloud.ai.translate.v2.DetectLanguageResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/translate/v2/detect:\x01*\x12\x9c\x01\n\rListLanguages\x12\x32.yandex.cloud.ai.translate.v2.ListLanguagesRequest\x1a\x33.yandex.cloud.ai.translate.v2.ListLanguagesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/translate/v2/languages:\x01*Bn\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.translate.v2.translation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translate'
  _TRANSLATEREQUEST.fields_by_name['source_language_code']._options = None
  _TRANSLATEREQUEST.fields_by_name['source_language_code']._serialized_options = b'\212\3101\003<=3'
  _TRANSLATEREQUEST.fields_by_name['target_language_code']._options = None
  _TRANSLATEREQUEST.fields_by_name['target_language_code']._serialized_options = b'\350\3071\001\212\3101\003<=3'
  _TRANSLATEREQUEST.fields_by_name['texts']._options = None
  _TRANSLATEREQUEST.fields_by_name['texts']._serialized_options = b'\202\3101\002>0'
  _TRANSLATEREQUEST.fields_by_name['folder_id']._options = None
  _TRANSLATEREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _TRANSLATEREQUEST.fields_by_name['model']._options = None
  _TRANSLATEREQUEST.fields_by_name['model']._serialized_options = b'\212\3101\004<=50'
  _TRANSLATEGLOSSARYCONFIG.oneofs_by_name['glossary_source']._options = None
  _TRANSLATEGLOSSARYCONFIG.oneofs_by_name['glossary_source']._serialized_options = b'\300\3011\001'
  _GLOSSARYDATA.fields_by_name['glossary_pairs']._options = None
  _GLOSSARYDATA.fields_by_name['glossary_pairs']._serialized_options = b'\202\3101\0041-50'
  _GLOSSARYPAIR.fields_by_name['source_text']._options = None
  _GLOSSARYPAIR.fields_by_name['source_text']._serialized_options = b'\350\3071\001'
  _GLOSSARYPAIR.fields_by_name['translated_text']._options = None
  _GLOSSARYPAIR.fields_by_name['translated_text']._serialized_options = b'\350\3071\001'
  _DETECTLANGUAGEREQUEST.fields_by_name['text']._options = None
  _DETECTLANGUAGEREQUEST.fields_by_name['text']._serialized_options = b'\350\3071\001\212\3101\006<=1000'
  _DETECTLANGUAGEREQUEST.fields_by_name['language_code_hints']._options = None
  _DETECTLANGUAGEREQUEST.fields_by_name['language_code_hints']._serialized_options = b'\202\3101\004<=10\212\3101\003<=3'
  _DETECTLANGUAGEREQUEST.fields_by_name['folder_id']._options = None
  _DETECTLANGUAGEREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _LISTLANGUAGESREQUEST.fields_by_name['folder_id']._options = None
  _LISTLANGUAGESREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _TRANSLATIONSERVICE.methods_by_name['Translate']._options = None
  _TRANSLATIONSERVICE.methods_by_name['Translate']._serialized_options = b'\202\323\344\223\002\034\"\027/translate/v2/translate:\001*'
  _TRANSLATIONSERVICE.methods_by_name['DetectLanguage']._options = None
  _TRANSLATIONSERVICE.methods_by_name['DetectLanguage']._serialized_options = b'\202\323\344\223\002\031\"\024/translate/v2/detect:\001*'
  _TRANSLATIONSERVICE.methods_by_name['ListLanguages']._options = None
  _TRANSLATIONSERVICE.methods_by_name['ListLanguages']._serialized_options = b'\202\323\344\223\002\034\"\027/translate/v2/languages:\001*'
  _globals['_TRANSLATEREQUEST']._serialized_start=198
  _globals['_TRANSLATEREQUEST']._serialized_end=603
  _globals['_TRANSLATEREQUEST_FORMAT']._serialized_start=545
  _globals['_TRANSLATEREQUEST_FORMAT']._serialized_end=603
  _globals['_TRANSLATEGLOSSARYCONFIG']._serialized_start=605
  _globals['_TRANSLATEGLOSSARYCONFIG']._serialized_end=724
  _globals['_GLOSSARYDATA']._serialized_start=726
  _globals['_GLOSSARYDATA']._serialized_end=818
  _globals['_GLOSSARYPAIR']._serialized_start=820
  _globals['_GLOSSARYPAIR']._serialized_end=907
  _globals['_TRANSLATERESPONSE']._serialized_start=909
  _globals['_TRANSLATERESPONSE']._serialized_end=996
  _globals['_DETECTLANGUAGEREQUEST']._serialized_start=999
  _globals['_DETECTLANGUAGEREQUEST']._serialized_end=1127
  _globals['_DETECTLANGUAGERESPONSE']._serialized_start=1129
  _globals['_DETECTLANGUAGERESPONSE']._serialized_end=1176
  _globals['_LISTLANGUAGESREQUEST']._serialized_start=1178
  _globals['_LISTLANGUAGESREQUEST']._serialized_end=1229
  _globals['_LISTLANGUAGESRESPONSE']._serialized_start=1231
  _globals['_LISTLANGUAGESRESPONSE']._serialized_end=1313
  _globals['_TRANSLATIONSERVICE']._serialized_start=1316
  _globals['_TRANSLATIONSERVICE']._serialized_end=1801
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/ydb/v1/database.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/ydb/v1/backup.proto\"\xb3\t\n\x08\x44\x61tabase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.yandex.cloud.ydb.v1.Database.Status\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\t \x01(\t\x12:\n\x0estorage_config\x18\n \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x0b \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x0c \x01(\t\x12\x12\n\nsubnet_ids\x18\r \x03(\t\x12<\n\x0ezonal_database\x18\x0e \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0f \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x12 \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x13 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x10 \x01(\x08\x12\x13\n\x0blocation_id\x18\x11 \x01(\t\x12\x39\n\x06labels\x18\x14 \x03(\x0b\x32).yandex.cloud.ydb.v1.Database.LabelsEntry\x12\x38\n\rbackup_config\x18\x15 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12\x1d\n\x15\x64ocument_api_endpoint\x18\x16 \x01(\t\x12\x1c\n\x14kinesis_api_endpoint\x18\x17 \x01(\t\x12\x1a\n\x12kafka_api_endpoint\x18\x1a \x01(\t\x12@\n\x11monitoring_config\x18\x18 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x19 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x42\x0f\n\rdatabase_typeJ\x04\x08\x07\x10\x08\"\x82\x06\n\x0e\x41lertParameter\x12Z\n\x16\x64ouble_parameter_value\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValueH\x00\x12\\\n\x17integer_parameter_value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValueH\x00\x12V\n\x14text_parameter_value\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.ydb.v1.AlertParameter.TextParameterValueH\x00\x12_\n\x19text_list_parameter_value\x18\x04 \x01(\x0b\x32:.yandex.cloud.ydb.v1.AlertParameter.TextListParameterValueH\x00\x12\x61\n\x1alabel_list_parameter_value\x18\x05 \x01(\x0b\x32;.yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValueH\x00\x1a\x33\n\x14\x44oubleParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x1a\x34\n\x15IntegerParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\x1a\x31\n\x12TextParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x36\n\x16TextListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\x1a\x37\n\x17LabelListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\tB\x0b\n\tparameter\"\xa2\x01\n\x13NotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12I\n\x15notify_about_statuses\x18\x02 \x03(\x0e\x32*.yandex.cloud.ydb.v1.AlertEvaluationStatus\x12\x1f\n\x17repeate_notify_delay_ms\x18\x03 \x01(\x03\"\x9e\x02\n\x05\x41lert\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x19\n\x11\x61lert_template_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12G\n\x15notification_channels\x18\x05 \x03(\x0b\x32(.yandex.cloud.ydb.v1.NotificationChannel\x12=\n\x10\x61lert_parameters\x18\x06 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\x12=\n\x10\x61lert_thresholds\x18\x07 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\">\n\x10MonitoringConfig\x12*\n\x06\x61lerts\x18\x01 \x03(\x0b\x32\x1a.yandex.cloud.ydb.v1.Alert\"\xe6\x01\n\x11\x44\x65\x64icatedDatabase\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12:\n\x0estorage_config\x18\x02 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x03 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x04 \x01(\t\x12\x12\n\nsubnet_ids\x18\x05 \x03(\t\x12\x19\n\x11\x61ssign_public_ips\x18\x06 \x01(\x08\"\xad\x01\n\x12ServerlessDatabase\x12\x1c\n\x14throttling_rcu_limit\x18\x01 \x01(\x03\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\x12#\n\x1b\x65nable_throttling_rcu_limit\x18\x03 \x01(\x08\x12\x1d\n\x15provisioned_rcu_limit\x18\x04 \x01(\x03\x12\x19\n\x11topic_write_quota\x18\x05 \x01(\x03\"&\n\rZonalDatabase\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x10RegionalDatabase\x12\x17\n\tregion_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x0bScalePolicy\x12\x42\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32+.yandex.cloud.ydb.v1.ScalePolicy.FixedScaleH\x00\x1a#\n\nFixedScale\x12\x15\n\x04size\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"q\n\rStorageConfig\x12\x44\n\x0fstorage_options\x18\x01 \x03(\x0b\x32\".yandex.cloud.ydb.v1.StorageOptionB\x07\x82\xc8\x31\x03>=1\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\"=\n\rStorageOption\x12\x17\n\x0fstorage_type_id\x18\x01 \x01(\t\x12\x13\n\x0bgroup_count\x18\x02 \x01(\x03*\xed\x01\n\x15\x41lertEvaluationStatus\x12\'\n#ALERT_EVALUATION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41LERT_EVALUATION_STATUS_OK\x10\x01\x12#\n\x1f\x41LERT_EVALUATION_STATUS_NO_DATA\x10\x02\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ERROR\x10\x03\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ALARM\x10\x04\x12 \n\x1c\x41LERT_EVALUATION_STATUS_WARN\x10\x05\x42V\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.database_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _DATABASE_LABELSENTRY._options = None
  _DATABASE_LABELSENTRY._serialized_options = b'8\001'
  _ZONALDATABASE.fields_by_name['zone_id']._options = None
  _ZONALDATABASE.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _REGIONALDATABASE.fields_by_name['region_id']._options = None
  _REGIONALDATABASE.fields_by_name['region_id']._serialized_options = b'\350\3071\001'
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._serialized_options = b'\372\3071\003>=1'
  _SCALEPOLICY.oneofs_by_name['scale_type']._options = None
  _SCALEPOLICY.oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _STORAGECONFIG.fields_by_name['storage_options']._options = None
  _STORAGECONFIG.fields_by_name['storage_options']._serialized_options = b'\202\3101\003>=1'
  _globals['_ALERTEVALUATIONSTATUS']._serialized_start=3468
  _globals['_ALERTEVALUATIONSTATUS']._serialized_end=3705
  _globals['_DATABASE']._serialized_start=158
  _globals['_DATABASE']._serialized_end=1361
  _globals['_DATABASE_LABELSENTRY']._serialized_start=1161
  _globals['_DATABASE_LABELSENTRY']._serialized_end=1206
  _globals['_DATABASE_STATUS']._serialized_start=1209
  _globals['_DATABASE_STATUS']._serialized_end=1338
  _globals['_ALERTPARAMETER']._serialized_start=1364
  _globals['_ALERTPARAMETER']._serialized_end=2134
  _globals['_ALERTPARAMETER_DOUBLEPARAMETERVALUE']._serialized_start=1852
  _globals['_ALERTPARAMETER_DOUBLEPARAMETERVALUE']._serialized_end=1903
  _globals['_ALERTPARAMETER_INTEGERPARAMETERVALUE']._serialized_start=1905
  _globals['_ALERTPARAMETER_INTEGERPARAMETERVALUE']._serialized_end=1957
  _globals['_ALERTPARAMETER_TEXTPARAMETERVALUE']._serialized_start=1959
  _globals['_ALERTPARAMETER_TEXTPARAMETERVALUE']._serialized_end=2008
  _globals['_ALERTPARAMETER_TEXTLISTPARAMETERVALUE']._serialized_start=2010
  _globals['_ALERTPARAMETER_TEXTLISTPARAMETERVALUE']._serialized_end=2064
  _globals['_ALERTPARAMETER_LABELLISTPARAMETERVALUE']._serialized_start=2066
  _globals['_ALERTPARAMETER_LABELLISTPARAMETERVALUE']._serialized_end=2121
  _globals['_NOTIFICATIONCHANNEL']._serialized_start=2137
  _globals['_NOTIFICATIONCHANNEL']._serialized_end=2299
  _globals['_ALERT']._serialized_start=2302
  _globals['_ALERT']._serialized_end=2588
  _globals['_MONITORINGCONFIG']._serialized_start=2590
  _globals['_MONITORINGCONFIG']._serialized_end=2652
  _globals['_DEDICATEDDATABASE']._serialized_start=2655
  _globals['_DEDICATEDDATABASE']._serialized_end=2885
  _globals['_SERVERLESSDATABASE']._serialized_start=2888
  _globals['_SERVERLESSDATABASE']._serialized_end=3061
  _globals['_ZONALDATABASE']._serialized_start=3063
  _globals['_ZONALDATABASE']._serialized_end=3101
  _globals['_REGIONALDATABASE']._serialized_start=3103
  _globals['_REGIONALDATABASE']._serialized_end=3146
  _globals['_SCALEPOLICY']._serialized_start=3149
  _globals['_SCALEPOLICY']._serialized_end=3287
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=3232
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=3267
  _globals['_STORAGECONFIG']._serialized_start=3289
  _globals['_STORAGECONFIG']._serialized_end=3402
  _globals['_STORAGEOPTION']._serialized_start=3404
  _globals['_STORAGEOPTION']._serialized_end=3465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/user_ssh_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/user_ssh_key.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd6\x01\n\nUserSshKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsubject_id\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\x17\n\x0forganization_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_ssh_key_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_USERSSHKEY']._serialized_start=129
  _globals['_USERSSHKEY']._serialized_end=343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadbalancer/v1/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/loadbalancer/v1/health_check.proto\x12\x1cyandex.cloud.loadbalancer.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\xf5\x03\n\x0bHealthCheck\x12\x33\n\x04name\x18\x01 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x13unhealthy_threshold\x18\x04 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x32-10\x12#\n\x11healthy_threshold\x18\x05 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x32-10\x12K\n\x0btcp_options\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.loadbalancer.v1.HealthCheck.TcpOptionsH\x00\x12M\n\x0chttp_options\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.loadbalancer.v1.HealthCheck.HttpOptionsH\x00\x1a\'\n\nTcpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x1a\x36\n\x0bHttpOptions\x12\x19\n\x04port\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65535\x12\x0c\n\x04path\x18\x02 \x01(\tB\x0f\n\x07options\x12\x04\xc0\xc1\x31\x01\x42q\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadbalancer.v1.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.loadbalancer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadbalancer/v1;loadbalancer'
  _HEALTHCHECK_TCPOPTIONS.fields_by_name['port']._options = None
  _HEALTHCHECK_TCPOPTIONS.fields_by_name['port']._serialized_options = b'\372\3071\0071-65535'
  _HEALTHCHECK_HTTPOPTIONS.fields_by_name['port']._options = None
  _HEALTHCHECK_HTTPOPTIONS.fields_by_name['port']._serialized_options = b'\372\3071\0071-65535'
  _HEALTHCHECK.oneofs_by_name['options']._options = None
  _HEALTHCHECK.oneofs_by_name['options']._serialized_options = b'\300\3011\001'
  _HEALTHCHECK.fields_by_name['name']._options = None
  _HEALTHCHECK.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._serialized_options = b'\372\3071\0042-10'
  _HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['healthy_threshold']._serialized_options = b'\372\3071\0042-10'
  _globals['_HEALTHCHECK']._serialized_start=145
  _globals['_HEALTHCHECK']._serialized_end=646
  _globals['_HEALTHCHECK_TCPOPTIONS']._serialized_start=534
  _globals['_HEALTHCHECK_TCPOPTIONS']._serialized_end=573
  _globals['_HEALTHCHECK_HTTPOPTIONS']._serialized_start=575
  _globals['_HEALTHCHECK_HTTPOPTIONS']._serialized_end=629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.clickhouse.v1.config import clickhouse_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_config_dot_clickhouse__pb2
from yandex.cloud.mdb.clickhouse.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/clickhouse/v1/cluster.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x36yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto\x1a\x30yandex/cloud/mdb/clickhouse/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"\xc8\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.mdb.clickhouse.v1.Cluster.LabelsEntry\x12H\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.clickhouse.v1.Cluster.Environment\x12>\n\nmonitoring\x18\x08 \x03(\x0b\x32*.yandex.cloud.mdb.clickhouse.v1.Monitoring\x12=\n\x06\x63onfig\x18\t \x01(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12>\n\x06health\x18\x0b \x01(\x0e\x32..yandex.cloud.mdb.clickhouse.v1.Cluster.Health\x12>\n\x06status\x18\x0c \x01(\x0e\x32..yandex.cloud.mdb.clickhouse.v1.Cluster.Status\x12\x1a\n\x12service_account_id\x18\r \x01(\t\x12M\n\x12maintenance_window\x18\x0e \x01(\x0b\x32\x31.yandex.cloud.mdb.clickhouse.v1.MaintenanceWindow\x12O\n\x11planned_operation\x18\x0f \x01(\x0b\x32\x34.yandex.cloud.mdb.clickhouse.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x10 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x11 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xbb\x06\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12L\n\nclickhouse\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.clickhouse.v1.ClusterConfig.Clickhouse\x12J\n\tzookeeper\x18\x03 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.ClusterConfig.Zookeeper\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x36\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32&.yandex.cloud.mdb.clickhouse.v1.Access\x12\x43\n\rcloud_storage\x18\x06 \x01(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.CloudStorage\x12;\n\x17sql_database_management\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13sql_user_management\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x65mbedded_keeper\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x96\x01\n\nClickhouse\x12J\n\x06\x63onfig\x18\x01 \x01(\x0b\x32:.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigSet\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x1aI\n\tZookeeper\x12<\n\tresources\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\"f\n\x05Shard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12;\n\x06\x63onfig\x18\x03 \x01(\x0b\x32+.yandex.cloud.mdb.clickhouse.v1.ShardConfig\"?\n\x06Shards\x12\x35\n\x06shards\x18\x01 \x03(\x0b\x32%.yandex.cloud.mdb.clickhouse.v1.Shard\"X\n\nShardGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0bshard_names\x18\x04 \x03(\t\"\x9f\x02\n\x0bShardConfig\x12J\n\nclickhouse\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.clickhouse.v1.ShardConfig.Clickhouse\x1a\xc3\x01\n\nClickhouse\x12J\n\x06\x63onfig\x18\x01 \x01(\x0b\x32:.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigSet\x12<\n\tresources\x18\x02 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x12+\n\x06weight\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xe0\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).yandex.cloud.mdb.clickhouse.v1.Host.Type\x12<\n\tresources\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Resources\x12;\n\x06health\x18\x06 \x01(\x0e\x32+.yandex.cloud.mdb.clickhouse.v1.Host.Health\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.yandex.cloud.mdb.clickhouse.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12\x12\n\nshard_name\x18\n \x01(\t\";\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCLICKHOUSE\x10\x01\x12\r\n\tZOOKEEPER\x10\x02\"8\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xee\x01\n\x07Service\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.yandex.cloud.mdb.clickhouse.v1.Service.Type\x12>\n\x06health\x18\x02 \x01(\x0e\x32..yandex.cloud.mdb.clickhouse.v1.Service.Health\";\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCLICKHOUSE\x10\x01\x12\r\n\tZOOKEEPER\x10\x02\"*\n\x06Health\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"~\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x0f\n\x07metrika\x18\x03 \x01(\x08\x12\x12\n\nserverless\x18\x04 \x01(\x08\x12\x15\n\rdata_transfer\x18\x05 \x01(\x08\x12\x14\n\x0cyandex_query\x18\x06 \x01(\x08\"\x86\x02\n\x0c\x43loudStorage\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12:\n\x0bmove_factor\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x07\xfa\xc7\x31\x03\x30-1\x12\x36\n\x12\x64\x61ta_cache_enabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x13\x64\x61ta_cache_max_size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13prefer_not_to_merge\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDSTORAGE.fields_by_name['move_factor']._options = None
  _CLOUDSTORAGE.fields_by_name['move_factor']._serialized_options = b'\372\3071\0030-1'
  _globals['_CLUSTER']._serialized_start=312
  _globals['_CLUSTER']._serialized_end=1408
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1100
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1145
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1147
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1220
  _globals['_CLUSTER_HEALTH']._serialized_start=1222
  _globals['_CLUSTER_HEALTH']._serialized_end=1285
  _globals['_CLUSTER_STATUS']._serialized_start=1287
  _globals['_CLUSTER_STATUS']._serialized_end=1408
  _globals['_MONITORING']._serialized_start=1410
  _globals['_MONITORING']._serialized_end=1471
  _globals['_CLUSTERCONFIG']._serialized_start=1474
  _globals['_CLUSTERCONFIG']._serialized_end=2301
  _globals['_CLUSTERCONFIG_CLICKHOUSE']._serialized_start=2076
  _globals['_CLUSTERCONFIG_CLICKHOUSE']._serialized_end=2226
  _globals['_CLUSTERCONFIG_ZOOKEEPER']._serialized_start=2228
  _globals['_CLUSTERCONFIG_ZOOKEEPER']._serialized_end=2301
  _globals['_SHARD']._serialized_start=2303
  _globals['_SHARD']._serialized_end=2405
  _globals['_SHARDS']._serialized_start=2407
  _globals['_SHARDS']._serialized_end=2470
  _globals['_SHARDGROUP']._serialized_start=2472
  _globals['_SHARDGROUP']._serialized_end=2560
  _globals['_SHARDCONFIG']._serialized_start=2563
  _globals['_SHARDCONFIG']._serialized_end=2850
  _globals['_SHARDCONFIG_CLICKHOUSE']._serialized_start=2655
  _globals['_SHARDCONFIG_CLICKHOUSE']._serialized_end=2850
  _globals['_HOST']._serialized_start=2853
  _globals['_HOST']._serialized_end=3333
  _globals['_HOST_TYPE']._serialized_start=3216
  _globals['_HOST_TYPE']._serialized_end=3275
  _globals['_HOST_HEALTH']._serialized_start=3277
  _globals['_HOST_HEALTH']._serialized_end=3333
  _globals['_SERVICE']._serialized_start=3336
  _globals['_SERVICE']._serialized_end=3574
  _globals['_SERVICE_TYPE']._serialized_start=3216
  _globals['_SERVICE_TYPE']._serialized_end=3275
  _globals['_SERVICE_HEALTH']._serialized_start=3277
  _globals['_SERVICE_HEALTH']._serialized_end=3319
  _globals['_RESOURCES']._serialized_start=3576
  _globals['_RESOURCES']._serialized_end=3656
  _globals['_ACCESS']._serialized_start=3658
  _globals['_ACCESS']._serialized_end=3784
  _globals['_CLOUDSTORAGE']._serialized_start=3787
  _globals['_CLOUDSTORAGE']._serialized_end=4049
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Health:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Health.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HEALTH_UNKNOWN: _Health.ValueType  # 0
    """Cluster is in unknown state (we have no data)."""
    ALIVE: _Health.ValueType  # 1
    """Cluster is alive and well."""
    DEAD: _Health.ValueType  # 2
    """Cluster is inoperable (it cannot perform any of its essential functions)."""
    DEGRADED: _Health.ValueType  # 3
    """Cluster is partially alive (it can perform some of its essential functions)."""

class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...

HEALTH_UNKNOWN: Health.ValueType  # 0
"""Cluster is in unknown state (we have no data)."""
ALIVE: Health.ValueType  # 1
"""Cluster is alive and well."""
DEAD: Health.ValueType  # 2
"""Cluster is inoperable (it cannot perform any of its essential functions)."""
DEGRADED: Health.ValueType  # 3
"""Cluster is partially alive (it can perform some of its essential functions)."""
global___Health = Health

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to an instance (CPU, memory etc.)."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateS3Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S3_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    s3_id: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        s3_id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "s3_id", b"s3_id"]) -> None: ...

global___ActivateS3Request = ActivateS3Request

@typing.final
class DeactivateS3Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S3_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    s3_id: builtins.str
    project_id: builtins.str
    def __init__(
        self,
        *,
        s3_id: builtins.str = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "s3_id", b"s3_id"]) -> None: ...

global___DeactivateS3Request = DeactivateS3Request
